; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   Name= "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.


[Command]
name = "AI_1"
command = U,D,F,F,B,B
time = 1

[Command]
name = "AI_2"
command = U,D,F,F,B,F
time = 1

[Command]
name = "AI_3"
command = U,D,F,F,B,D
time = 1

[Command]
name = "AI_4"
command = U,D,F,F,B,U
time = 1

[Command]
name = "AI_5"
command = U,D,F,F,U,B
time = 1

[Command]
name = "AI_6"
command = U,D,F,F,D,B
time = 1

[Command]
name = "AI_7"
command = U,D,F,F,F,B
time = 1

[Command]
name = "AI_8"
command = U,D,U,F,B,B
time = 1

[Command]
name = "AI_9"
command = U,D,D,F,B,B
time = 1

[Command]
name = "AI_10"
command = D,D,F,F,B,B
time = 1

[Command]
name = "AI_11"
command = U,U,F,F,B,B
time = 1

[Command]
name = "AI_12"
command = U,B,F,F,B,B
time = 1


[Command]
name = "Agarra_x"
command = ~D,B,a

[Command]
name = "Agarra_x"
command = ~D,B,b

[Command]
name = "Agarra_x"
command = ~D,B,c

[Command]
name = "Power_x"
command = ~B,D,B,x

[Command]
name = "Power_x"
command = ~B,D,B,y

[Command]
name = "Power_x"
command = ~B,D,B,z

[Command]
name = "Golpe_a"
command = ~D,F,a

[Command]
name = "Golpe_b"
command = ~D,F,b

[Command]
name = "Golpe_c"
command = ~D,F,c

[Command]
name = "Frente_z"
command = ~z

[Command]
name = "Mag_x"
command = ~D,B,x

[Command]
name = "Mag_y"
command = ~D,B,y

[Command]
name = "Mag_z"
command = ~D,B,z

[Command]
name = "Esp_1"
command = ~D,F,y+x

[Command]
name = "Golpe_x"
command = ~D,F,x

[Command]
name = "Golpe_y"
command = ~D,F,y

[Command]
name = "Golpe_z"
command = ~D,F,z

[Command]
name = "Supa_Jumpin"
command = $D, U

[Command]
name = "Supa_Jumpin"
command = a+b+c

[Command]
name = "rola"
command = ~D,F,x+y

[Command]
name = "rola"
command = ~D,F,x+z

[Command]
name = "rola"
command = ~D,F,y+z

;=======================================================[Empurar_na_Defesa]=======================================
[Command]
name = "Empurar"
command = x+y

[Command]
name = "Empurar"
command = x+z

[Command]
name = "Empurar"
command = z+y

[Command]
name = "Empurar"
command = x+y+z

;-| Double Tap |-----------------------------------------------------------
[Command]
Name= "FF";Required (do not remove)
command = F, F
time = 10

[Command]
Name= "BB";Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
Name= "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
Name= "ab"
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
Name= "fwd_a"
command = /F,a
time = 1

[Command]
Name= "fwd_b"
command = /F,b
time = 1

[Command]
Name= "fwd_c"
command = /F,c
time = 1

[Command]
Name= "fwd_x"
command = /F,x
time = 1

[Command]
Name= "fwd_y"
command = /F,y
time = 1

[Command]
Name= "fwd_z"
command = /F,z
time = 1

[Command]
Name= "back_a"
command = /B,a
time = 1

[Command]
Name= "back_b"
command = /B,b
time = 1

[Command]
Name= "back_c"
command = /B,c
time = 1

[Command]
Name= "back_z"
command = /B,z
time = 1

[Command]
Name= "back_y"
command = /B,y
time = 1

[Command]
Name= "down_a"
command = /$D,a
time = 1

[Command]
Name= "down_b"
command = /$D,b
time = 1

[Command]
Name= "down_c"
command = /$D,c
time = 1

[Command]
Name= "fwd_ab"
command = /F, a+b
time = 1

[Command]
Name= "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
Name= "a"
command = a
time = 1

[Command]
Name= "b"
command = b
time = 1

[Command]
Name= "c"
command = c
time = 1

[Command]
Name= "x"
command = x
time = 1

[Command]
Name= "y"
command = y
time = 1

[Command]
Name= "z"
command = z
time = 1

[Command]
Name= "holdx"
command = /$x
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
Name= "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
Name= "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
Name= "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
Name= "holddown";Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1=command="command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]


[State -1]
type = ChangeState
value = 830
triggerall=command="Agarra_x"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 206
trigger4 = movecontact = 1
trigger5 = stateno = 216
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 210
trigger7 = movecontact = 1
trigger8 = stateno = 400
trigger8 = movecontact = 1 
trigger9 = stateno = 405
trigger9 = movecontact = 1
trigger10 = stateno = 406
trigger10 = movecontact = 1
trigger11 = stateno = 416
trigger11 = movecontact = 1
trigger12 = stateno = 415
trigger12 = movecontact = 1
trigger13 = stateno = 410
trigger13 = movecontact = 1

[State -1]
type = ChangeState
value = 1060
triggerall=command="Power_x"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Golpe Chute
[State -1]
type = ChangeState
value = 1040
triggerall=command="Golpe_a"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 206
trigger4 = movecontact = 1
trigger5 = stateno = 216
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 210
trigger7 = movecontact = 1
trigger8 = stateno = 400
trigger8 = movecontact = 1 
trigger9 = stateno = 405
trigger9 = movecontact = 1
trigger10 = stateno = 406
trigger10 = movecontact = 1
trigger11 = stateno = 416
trigger11 = movecontact = 1
trigger12 = stateno = 415
trigger12 = movecontact = 1
trigger13 = stateno = 410
trigger13 = movecontact = 1
trigger14 = statetype = A
trigger14 = ctrl = 1

;---------------------------------------------------------------------------
;Golpe Chute
[State -1]
type = ChangeState
value = 1045
triggerall=command="Golpe_b"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 206
trigger4 = movecontact = 1
trigger5 = stateno = 216
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 210
trigger7 = movecontact = 1
trigger8 = stateno = 400
trigger8 = movecontact = 1 
trigger9 = stateno = 405
trigger9 = movecontact = 1
trigger10 = stateno = 406
trigger10 = movecontact = 1
trigger11 = stateno = 416
trigger11 = movecontact = 1
trigger12 = stateno = 415
trigger12 = movecontact = 1
trigger13 = stateno = 410
trigger13 = movecontact = 1
trigger14 = statetype = A
trigger14 = ctrl = 1


;---------------------------------------------------------------------------
;Golpe Chute
[State -1]
type = ChangeState
value = 1050
triggerall=command="Golpe_c"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 206
trigger4 = movecontact = 1
trigger5 = stateno = 216
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 210
trigger7 = movecontact = 1
trigger8 = stateno = 400
trigger8 = movecontact = 1 
trigger9 = stateno = 405
trigger9 = movecontact = 1
trigger10 = stateno = 406
trigger10 = movecontact = 1
trigger11 = stateno = 416
trigger11 = movecontact = 1
trigger12 = stateno = 415
trigger12 = movecontact = 1
trigger13 = stateno = 410
trigger13 = movecontact = 1
trigger14 = statetype = A
trigger14 = ctrl = 1

;---------------------------------------------------------------------------
;Soco Forte
[State -1]
type = ChangeState
value = 1020
triggerall=command="Mag_x"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 206
trigger4 = movecontact = 1
trigger5 = stateno = 216
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 210
trigger7 = movecontact = 1
trigger8 = stateno = 400
trigger8 = movecontact = 1 
trigger9 = stateno = 405
trigger9 = movecontact = 1
trigger10 = stateno = 406
trigger10 = movecontact = 1
trigger11 = stateno = 416
trigger11 = movecontact = 1
trigger12 = stateno = 415
trigger12 = movecontact = 1
trigger13 = stateno = 410
trigger13 = movecontact = 1

;---------------------------------------------------------------------------
;Soco Forte
[State -1]
type = ChangeState
value = 1025
triggerall=command="Mag_y"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 206
trigger4 = movecontact = 1
trigger5 = stateno = 216
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 210
trigger7 = movecontact = 1
trigger8 = stateno = 400
trigger8 = movecontact = 1 
trigger9 = stateno = 405
trigger9 = movecontact = 1
trigger10 = stateno = 406
trigger10 = movecontact = 1
trigger11 = stateno = 416
trigger11 = movecontact = 1
trigger12 = stateno = 415
trigger12 = movecontact = 1
trigger13 = stateno = 410
trigger13 = movecontact = 1


;---------------------------------------------------------------------------
;Magia Forte
[State -1]
type = ChangeState
value = 1030
triggerall=command="Mag_z"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 206
trigger4 = movecontact = 1
trigger5 = stateno = 216
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 210
trigger7 = movecontact = 1
trigger8 = stateno = 400
trigger8 = movecontact = 1 
trigger9 = stateno = 405
trigger9 = movecontact = 1
trigger10 = stateno = 406
trigger10 = movecontact = 1
trigger11 = stateno = 416
trigger11 = movecontact = 1
trigger12 = stateno = 415
trigger12 = movecontact = 1
trigger13 = stateno = 410
trigger13 = movecontact = 1

;---------------------------------------------------------------------------
;Especial
[State -1]
type = ChangeState
value = 3000
triggerall=command="Esp_1"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 206
trigger4 = movecontact = 1
trigger5 = stateno = 216
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 210
trigger7 = movecontact = 1
trigger8 = stateno = 400
trigger8 = movecontact = 1 
trigger9 = stateno = 405
trigger9 = movecontact = 1
trigger10 = stateno = 406
trigger10 = movecontact = 1
trigger11 = stateno = 416
trigger11 = movecontact = 1
trigger12 = stateno = 415
trigger12 = movecontact = 1
trigger13 = stateno = 410
trigger13 = movecontact = 1

;---------------------------------------------------------------------------
;Soco Forte
[State -1]
type = ChangeState
value = 1000
triggerall=command="Golpe_x"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 206
trigger4 = movecontact = 1
trigger5 = stateno = 216
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 210
trigger7 = movecontact = 1
trigger8 = stateno = 400
trigger8 = movecontact = 1 
trigger9 = stateno = 405
trigger9 = movecontact = 1
trigger10 = stateno = 406
trigger10 = movecontact = 1
trigger11 = stateno = 416
trigger11 = movecontact = 1
trigger12 = stateno = 415
trigger12 = movecontact = 1
trigger13 = stateno = 410
trigger13 = movecontact = 1

;---------------------------------------------------------------------------
;Soco Forte
[State -1]
type = ChangeState
value = 1005
triggerall=command="Golpe_y"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 206
trigger4 = movecontact = 1
trigger5 = stateno = 216
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 210
trigger7 = movecontact = 1
trigger8 = stateno = 400
trigger8 = movecontact = 1 
trigger9 = stateno = 405
trigger9 = movecontact = 1
trigger10 = stateno = 406
trigger10 = movecontact = 1
trigger11 = stateno = 416
trigger11 = movecontact = 1
trigger12 = stateno = 415
trigger12 = movecontact = 1
trigger13 = stateno = 410
trigger13 = movecontact = 1

;---------------------------------------------------------------------------
;Soco Forte
[State -1]
type = ChangeState
value = 1010
triggerall=command="Golpe_z"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 206
trigger4 = movecontact = 1
trigger5 = stateno = 216
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 210
trigger7 = movecontact = 1
trigger8 = stateno = 400
trigger8 = movecontact = 1 
trigger9 = stateno = 405
trigger9 = movecontact = 1
trigger10 = stateno = 406
trigger10 = movecontact = 1
trigger11 = stateno = 416
trigger11 = movecontact = 1
trigger12 = stateno = 415
trigger12 = movecontact = 1
trigger13 = stateno = 410
trigger13 = movecontact = 1


[State -1]
type = ChangeState
value = 810
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 10 ;Near P2
trigger1=command="fwd_z";p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2=command="fwd_z";p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
trigger3=command="back_z";p2 stand
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4=command="back_z";p2 crouch
trigger4 = p2statetype = C
trigger4 = p2movetype != H


[State -1]
type = ChangeState
value = 820
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 10 ;Near P2
trigger1=command="fwd_y";p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2=command="fwd_y";p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
trigger3=command="back_y";p2 stand
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4=command="back_y";p2 crouch
trigger4 = p2statetype = C
trigger4 = p2movetype != H

;---------------------------------------------------------------------------
;SuperPulo
[State -1]
type = ChangeState
value = 5400
triggerall = command = "Supa_Jumpin"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 406
trigger2 = movecontact = 1


;-----------------------------------
;Empurar oponente quando defendendo
[State -1]
type = ChangeState
value = 1120
triggerall = command = "Empurar"
trigger1 = stateno = 150
trigger2 = stateno = 151

;---------------------------------------------------------------------------
;Correr P/ Frente
[State -1]
type = ChangeState
value = 100
trigger1=command="FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Correr p/ Trs
[State -1]
type = ChangeState
value = 105
trigger1=command="BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Soco Fraco
[State -1]
type = ChangeState
value = 200
triggerall=command="x"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Soco Medio
[State -1]
type = ChangeState
value = 205
triggerall=command="y"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 
trigger3 = stateno = 216
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Soco Forte
[State -1]
type = ChangeState
value = 206
trigger1=command="Frente_z"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2=command="back_z"
trigger2 = statetype = S
trigger2 = ctrl = 1

;---------------------------------------------------------------------------
;Soco Forte	Frente
[State -1]
type = ChangeState
value = 207
triggerall=command="fwd_z"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Chute Forte
[State -1]
type = ChangeState
value = 210
triggerall=command="c"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 205
trigger2 = movecontact = 1 
trigger3 = stateno = 206
trigger3 = movecontact = 1
trigger4 = stateno = 215
trigger4 = movecontact = 1
 
;---------------------------------------------------------------------------
;Chute Medio
[State -1]
type = ChangeState
value = 215
triggerall=command="b"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 216
trigger4 = movecontact = 1

;---------------------------------------------------------------------------
;Chute Fraco
[State -1]
type = ChangeState
value = 216
triggerall=command="a"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 

;---------------------------------------------------------------------------
;Rasteira c/ soco Fraco
[State -1]
type = ChangeState
value = 400
triggerall=command="x"
;triggerall=command="holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Rasteira c/ soco Medio
[State -1]
type = ChangeState
value = 405
triggerall=command="y"
;triggerall=command="holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400
trigger2 = movecontact = 1 
trigger3 = stateno = 416
trigger3 = movecontact = 1


;---------------------------------------------------------------------------
;Rasteira c/ soco Forte
[State -1]
type = ChangeState
value = 406
triggerall=command="z"
;triggerall=command="holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 405
trigger2 = movecontact = 1 
trigger3 = stateno = 415
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Rasteira c/ Chute Forte
[State -1]
type = ChangeState
value = 410
triggerall=command="c"
triggerall=command="holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 405
trigger2 = movecontact = 1 
trigger3 = stateno = 415
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Rasteira c/ Chute Medio
[State -1]
type = ChangeState
value = 415
triggerall=command="b"
triggerall=command="holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400
trigger2 = movecontact = 1 
trigger3 = stateno = 405
trigger3 = movecontact = 1
trigger4 = stateno = 416
trigger4 = movecontact = 1

;---------------------------------------------------------------------------
;Rasteira c/ Chute Fraco
[State -1]
type = ChangeState
value = 416
triggerall=command="a"
triggerall=command="holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400
trigger2 = movecontact = 1 

;---------------------------------------------------------------------------
;Voadora c/ Soco Fraco
[State -1]
type = ChangeState
value = 600
triggerall=command="x"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Voadora c/ Soco Medio
[State -1]
type = ChangeState
value = 601
triggerall=command="y"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1 
trigger3 = stateno = 615
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
; Voadora c/ Soco Forte
[State -1]
type = ChangeState
value = 605
triggerall=command="z"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1 
trigger3 = stateno = 601
trigger3 = movecontact = 1
trigger4 = stateno = 615
trigger4 = movecontact = 1
trigger5 = stateno = 611
trigger5 = movecontact = 1

;---------------------------------------------------------------------------
;  Voadora c/ Chute Forte
[State -1]
type = ChangeState
value = 610
triggerall=command="c"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1 
trigger3 = stateno = 601
trigger3 = movecontact = 1
trigger4 = stateno = 615
trigger4 = movecontact = 1
trigger5 = stateno = 611
trigger5 = movecontact = 1

;---------------------------------------------------------------------------
;  Voadora c/ Chute Medio
[State -1]
type = ChangeState
value = 611
triggerall=command="b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1 
trigger3 = stateno = 601
trigger3 = movecontact = 1
trigger4 = stateno = 615
trigger4 = movecontact = 1

;---------------------------------------------------------------------------
; Voadora c/ Chute Fraco
[State -1]
type = ChangeState
value = 615
triggerall=command="a"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1 
